@@ -217,7 +217,7 @@ stringpart *nextstringpart(stringpart *strptr, objinstptr thisinst)
       /* should be free'd.					*/
 
       if (strptr->data.string != (u_char *)NULL) {
-	 freelabel((stringpart *)(strptr->data.string));
+	 free(strptr->data.string);
 	 strptr->data.string = (u_char *)NULL;
       }
    }
@@ -237,8 +237,10 @@ stringpart *nextstringpartnorecompute(stringpart *strptr, objinstptr thisinst)
       nextptr = linkstring(thisinst, strptr, FALSE);
    else if (strptr->type == PARAM_END) {
       strptr->nextpart = NULL;
-      if (strptr->data.string != (u_char *)NULL)
-	 freelabel((stringpart *)(strptr->data.string));
+      if (strptr->data.string != (u_char *)NULL) {
+	 free(strptr->data.string);
+	 strptr->data.string = (u_char *)NULL;
+      }
    }
    return nextptr;
 }
@@ -1170,6 +1172,7 @@ stringpart *stringcopyback(stringpart *string, objinstptr thisinst)
       newpart = (stringpart *)malloc(sizeof(stringpart));
       newpart->type = strptr->type;
       newpart->nextpart = NULL;
+      newpart->data.string = NULL;
 
       if (strptr == string) rettop = newpart;	/* initial segment */
       else curend->nextpart = newpart;  	/* append segment to label */
